==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-tree-selection-options-event-args.js <==
import { IgrTreeSelectionOptionsEventDetail } from "./igr-tree-selection-options-event-detail";
import { TreeSelectionOptionsEventArgs as TreeSelectionOptionsEventArgs_internal } from "./TreeSelectionOptionsEventArgs";
var IgrTreeSelectionOptionsEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrTreeSelectionOptionsEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrTreeSelectionOptionsEventArgs.prototype.createImplementation = function () {
        return new TreeSelectionOptionsEventArgs_internal();
    };
    Object.defineProperty(IgrTreeSelectionOptionsEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrTreeSelectionOptionsEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrTreeSelectionOptionsEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrTreeSelectionOptionsEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.b == null) {
                return null;
            }
            if (!this.i.b.externalObject) {
                var e = new IgrTreeSelectionOptionsEventDetail();
                e._implementation = this.i.b;
                this.i.b.externalObject = e;
            }
            return this.i.b.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrTreeSelectionOptionsEventArgs;
}());
export { IgrTreeSelectionOptionsEventArgs };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-tree-selection-options-event-args.js <==
import { IgrTreeSelectionOptionsEventDetail } from "./igr-tree-selection-options-event-detail";
import { TreeSelectionOptionsEventArgs as TreeSelectionOptionsEventArgs_internal } from "./TreeSelectionOptionsEventArgs";
var IgrTreeSelectionOptionsEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrTreeSelectionOptionsEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrTreeSelectionOptionsEventArgs.prototype.createImplementation = function () {
        return new TreeSelectionOptionsEventArgs_internal();
    };
    Object.defineProperty(IgrTreeSelectionOptionsEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrTreeSelectionOptionsEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrTreeSelectionOptionsEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrTreeSelectionOptionsEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.b;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrTreeSelectionOptionsEventDetail();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrTreeSelectionOptionsEventArgs;
}());
export { IgrTreeSelectionOptionsEventArgs };
